@@ -8,6 +8,7 @@
 */
 
 /* .Call calls */
+extern SEXP R_afind(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_all_int(SEXP);
 extern SEXP R_amatch(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_get_qgrams(SEXP, SEXP);
@@ -17,6 +18,7 @@ extern SEXP R_soundex(SEXP, SEXP);
 extern SEXP R_stringdist(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
+    {"R_afind",      (DL_FUNC) &R_afind,      10},
     {"R_all_int",    (DL_FUNC) &R_all_int,     1},
     {"R_amatch",     (DL_FUNC) &R_amatch,     12},
     {"R_get_qgrams", (DL_FUNC) &R_get_qgrams,  2},
@@ -30,8 +32,8 @@ static const R_CallMethodDef CallEntries[] = {
 void R_init_stringdist(DllInfo *dll)
 {
     R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
-    R_useDynamicSymbols(dll, TRUE);
-    
+    R_useDynamicSymbols(dll, FALSE);
+
     /* used by external packages linking to internal xts code from C */
     R_RegisterCCallable("stringdist","R_all_int",(DL_FUNC) &R_all_int);
     R_RegisterCCallable("stringdist","R_amatch",(DL_FUNC) &R_amatch);
@@ -40,4 +42,5 @@ void R_init_stringdist(DllInfo *dll)
     R_RegisterCCallable("stringdist","R_lower_tri",(DL_FUNC) &R_lower_tri);
     R_RegisterCCallable("stringdist","R_soundex",(DL_FUNC) &R_soundex);
     R_RegisterCCallable("stringdist","R_stringdist",(DL_FUNC) &R_stringdist);
+
 }
